@@ -26,7 +26,6 @@ class BaseAdapter(ABC):
     """
 
     def __init__(self, initial_value, end_value, adaptive_rate, **kwargs):
-
         self.initial_value = initial_value
         self.end_value = end_value
         self.adaptive_rate = adaptive_rate
@@ -38,4 +37,4 @@ class BaseAdapter(ABC):
         """
         Run one iteration of the transformation
         """
-        raise NotImplementedError("Scheduler must override step()")
+        raise NotImplementedError("Scheduler must override step()")  # pragma: no cover
